state property
T
get
state
inherited
Gets the current state.
This is a getter that returns the current value from the underlying ValueNotifier.
Implementation
S get state => super.value;
Gets the current state.
This is a getter that returns the current value from the underlying ValueNotifier.
S get state => super.value;