SimpleVelo class
A simple test Velo implementation.
- Inheritance
-
- Object
- ChangeNotifier
- ValueNotifier<
SimpleState> - SimpleVelo
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → SimpleState
-
Gets the current state.
no setterinherited
- value ↔ SimpleState
-
The current value stored in this notifier.
getter/setter pairinherited
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
dispose(
) → void -
Discards any resources used by the object.
inherited
-
emit(
SimpleState state) → void -
Emits a new state if it's different from the current state.
inherited
-
emitAsync(
Future< SimpleState> futureState) → Future<void> -
Emits a state from a Future.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
setValue(
int value) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited