buildText function
Helper function to build a text widget from counter state.
Implementation
Widget buildText(BuildContext context, CounterState state) =>
Text('Count: ${state.count}');
Helper function to build a text widget from counter state.
Widget buildText(BuildContext context, CounterState state) =>
Text('Count: ${state.count}');