pumpAndSettle function
Pumps a widget and waits for all animations and microtasks to complete.
Implementation
Future<void> pumpAndSettle(WidgetTester tester, Widget widget) async {
await tester.pumpWidget(widget);
await tester.pumpAndSettle();
}
Pumps a widget and waits for all animations and microtasks to complete.
Future<void> pumpAndSettle(WidgetTester tester, Widget widget) async {
await tester.pumpWidget(widget);
await tester.pumpAndSettle();
}