isHistoryNearLimit property
bool
get
isHistoryNearLimit
Gets whether the history size is approaching the limit.
Returns true if the history contains more than 80% of _maxHistorySize.
This can be used to detect potential memory issues in tests.
Implementation
bool get isHistoryNearLimit => historySize > _maxHistorySize * 0.8;