VeloMatchers class
Custom matchers for Velo testing.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
emitsAnyOf<
S> (List< S> expectedStates) → Matcher - Matches when a Velo notifier emits any of the expected states.
-
emitsCount(
int expectedCount) → Matcher - Matches when a Velo notifier emits exactly the expected number of states.
-
emitsInOrder<
S> (List< S> expectedStates) → Matcher - Matches when a Velo notifier emits the expected states in order.
-
emitsWhere<
S> (bool predicate(S state)) → Matcher - Matches when a Velo notifier emits states that satisfy the given predicate.
-
hasState<
S> (S expectedState) → Matcher - Matches when a Velo notifier's current state equals the expected state.