VeloTestUtils class
Utility functions for Velo testing.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
collectStates<
S> (Velo< S> velo, Future<void> action()) → Future<List< S> > - Collects all states emitted by a Velo notifier during the execution of an action.
-
waitForState<
S> (Velo< S> velo, S expectedState, {Duration timeout = const Duration(seconds: 5)}) → Future<void> - Waits for a Velo notifier to emit a specific state.
-
waitForStateWhere<
S> (Velo< S> velo, bool predicate(S state), {Duration timeout = const Duration(seconds: 5)}) → Future<S> - Waits for a Velo notifier to emit any state that satisfies the predicate.